@@ -33,6 +33,8 @@ my @feed_attrs  = qw[Title Tagline Format Author Link Base
 my @entry_attrs = qw[Link Author Title Category Id Issued Modified
                      Lat Long Format Tags Enclosure Summary Content];
 
+my %use_body_attrs = map { $_ => 1 } qw[Summary Content];
+
 my $feed = XML::Feed->parse( $source ) or die XML::Feed->errstr;
 
 for (@feed_attrs) {
@@ -44,15 +46,20 @@ for my $entry ($feed->entries) {
   say '';
 
   for (@entry_attrs) {
-    my $method = lc $_;
-    my $data;
-    if (/^(Summary|Content)$/) {
-      $data = $entry->$method->body // '';
-    } else {
-      $data = $entry->$method // '';
-    }
-
-    printf(" * %-11s %s\n", "$_:", $data);
+    say get_attribute($entry, $_);
   }
 }
 
+sub get_attribute {
+  my ($entry, $attr) = @_;
+
+  my $method = lc $attr;
+  my $data;
+  if ($use_body_attrs{$attr}) {
+    $data = $entry->$method->body // '';
+  } else {
+    $data = $entry->$method // '';
+  }
+
+  return sprintf(" * %-11s %s", "$attr:", $data);
+}
